@@ -1,7 +1,7 @@
 ;;; module.scm  --  Execution environment for Skribilo documents.
 ;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2009  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2009, 2020  Ludovic Courts <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -20,10 +20,10 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo module)
-  :use-module (srfi srfi-1)
-  :use-module (srfi srfi-39)
-  :use-module (skribilo utils syntax)
-  :export (make-user-module user-module-flavor
+  #:use-module (srfi srfi-1)
+  #:use-module (srfi srfi-39)
+  #:use-module (skribilo utils syntax)
+  #:export (make-user-module user-module-flavor
            *skribilo-user-module*))
 
 (skribilo-module-syntax)
@@ -109,8 +109,7 @@
   ;;
   ;; Consequently, on Guile 2.x, we just let Guile choose a module name and
   ;; do the right thing.
-  (cond-expand ((not guile-2) set-module-name!)
-               (else          (lambda (m n) #t))))
+  (lambda (m n) #t))
 
 (define (make-skribe-user-module)
   "Return a new module that imports all the necessary bindings required for
