@@ -1,7 +1,6 @@
 ;;; output.scm  --  Skribilo output stage.
-;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2008, 2020  Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
 ;;;
 ;;;
@@ -22,20 +21,21 @@
 
 
 (define-module (skribilo output)
-  :autoload   (skribilo engine) (engine-ident processor-get-engine)
-  :autoload   (skribilo writer) (writer? writer-ident lookup-markup-writer)
-  :autoload   (skribilo location) (location?)
-  :use-module (skribilo ast)
-  :use-module (skribilo debug)
-  :use-module (skribilo utils syntax)
-  :use-module (oop goops)
+  #:autoload   (skribilo engine) (engine-ident processor-get-engine)
+  #:autoload   (skribilo writer) (<writer> writer? writer-ident
+                                  lookup-markup-writer invoke)
+  #:use-module (skribilo location)
+  #:use-module (skribilo ast)
+  #:use-module (skribilo debug)
+  #:use-module (skribilo utils syntax)
+  #:use-module (oop goops)
 
-  :use-module (skribilo condition)
-  :use-module (srfi srfi-35)
-  :use-module (srfi srfi-34)
-  :use-module (srfi srfi-39)
+  #:use-module (skribilo condition)
+  #:use-module (srfi srfi-35)
+  #:use-module (srfi srfi-34)
+  #:use-module (srfi srfi-39)
 
-  :export     (output
+  #:export     (output
 	       *document-being-output*
 	       &output-error &output-unresolved-error &output-writer-error
 	       output-error? output-unresolved-error? output-writer-error?))
